==> beidou-webpack-2.0.3.tgz: package/config/webpack/webpack.node.js <==
'use strict';

// Webpack config for node

const webpack = require('webpack');
const MinifyPlugin = require('babel-minify-webpack-plugin');
const common = require('./webpack.common');
const {
  imageLoaderConfig,
  fileLoaderConfig,
  getStyleCongfigs,
  ExtractTextPlugin,
} = require('./utils');

module.exports = (app, entry, dev) => {
  const factory = app.webpackFactory;
  common(app, entry, dev);
  factory.get('output').libraryTarget = 'commonjs';
  factory.set('target', 'node');
  factory.set('externals', /^react(-dom)?$/);
  factory.set('node', {
    __filename: true,
    __dirname: true,
  });

  [
    {
      test: /\.(js|jsx|mjs)$/,
      exclude: /node_modules/,
      use: {
        loader: require.resolve('babel-loader'),
        options: {
          babelrc: false,
          presets: [require.resolve('babel-preset-beidou-server')],
          // This is a feature of `babel-loader` for webpack (not Babel itself).
          // It enables caching results in ./node_modules/.cache/babel-loader/
          // directory for faster rebuilds.
          cacheDirectory: true,
          highlightCode: true,
        },
      },
    },
    ...getStyleCongfigs(dev),
    imageLoaderConfig,
    fileLoaderConfig,
  ].forEach((v) => {
    factory.defineRule(v).addRule(v);
  });

  factory
    .definePlugin(ExtractTextPlugin, '[name].css', 'ExtractTextPlugin')
    .addPlugin('ExtractTextPlugin');

  factory.definePlugin(
    webpack.DefinePlugin,
    {
      'process.env.NODE_ENV': JSON.stringify('production'),
      __CLIENT__: false,
      __DEV__: false,
      __SERVER__: true,
    },
    'DefinePlugin'
  );

  if (!dev) {
    factory.addPlugin('DefinePlugin');
    factory.addPlugin(MinifyPlugin, null, 'MinifyPlugin');
  } else {
    factory.setPlugin(
      webpack.DefinePlugin,
      {
        'process.env.NODE_ENV': JSON.stringify('development'),
        __CLIENT__: false,
        __DEV__: true,
        __SERVER__: true,
      },
      'DefinePlugin'
    );
  }
  return factory.getConfig();
};

==> beidou-webpack-2.1.0.tgz: package/config/webpack/webpack.node.js <==
'use strict';

// Webpack config for node

const webpack = require('webpack');
const MinifyPlugin = require('babel-minify-webpack-plugin');
const { common } = require('./webpack.common');
const {
  imageLoaderConfig,
  fileLoaderConfig,
  getStyleCongfigs,
  ExtractTextPlugin,
} = require('./utils');

module.exports = (app, entry, dev) => {
  const factory = app.webpackFactory;
  const viewConfig = app.config.view;
  common(app, entry, dev);
  factory.get('output').libraryTarget = 'commonjs';
  factory.set('target', 'node');
  factory.set('externals', /^react(-dom)?$/);
  factory.set('node', {
    __filename: true,
    __dirname: true,
  });

  [
    {
      test: /\.(js|jsx|mjs)$/,
      exclude: /node_modules/,
      use: {
        loader: require.resolve('babel-loader'),
        options: {
          babelrc: false,
          presets: [require.resolve('babel-preset-beidou-server')],
          // This is a feature of `babel-loader` for webpack (not Babel itself).
          // It enables caching results in ./node_modules/.cache/babel-loader/
          // directory for faster rebuilds.
          cacheDirectory: true,
          highlightCode: true,
        },
      },
    },
    ...getStyleCongfigs(dev),
    imageLoaderConfig,
    fileLoaderConfig,
  ].forEach((v) => {
    factory.defineRule(v).addRule(v);
  });
  if (!dev && viewConfig.useHashAsset) {
    factory.definePlugin(
      ExtractTextPlugin,
      '[name]_[md5:contenthash:hex:8].css',
      'ExtractTextPlugin'
    );
  } else {
    factory.definePlugin(ExtractTextPlugin, '[name].css', 'ExtractTextPlugin');
  }

  factory.addPlugin('ExtractTextPlugin');

  factory.definePlugin(
    webpack.DefinePlugin,
    {
      'process.env.NODE_ENV': JSON.stringify('production'),
      __CLIENT__: false,
      __DEV__: false,
      __SERVER__: true,
    },
    'DefinePlugin'
  );

  if (!dev) {
    factory.addPlugin('DefinePlugin');
    factory.addPlugin(MinifyPlugin, null, 'MinifyPlugin');
  } else {
    factory.setPlugin(
      webpack.DefinePlugin,
      {
        'process.env.NODE_ENV': JSON.stringify('development'),
        __CLIENT__: false,
        __DEV__: true,
        __SERVER__: true,
      },
      'DefinePlugin'
    );
  }
  return factory.getConfig();
};
